Skip to contents

Print a prLogistic object

Usage

# S3 method for class 'prLogistic'
print(x, digits = 4, ...)

Arguments

x

A prLogistic object.

digits

Number of significant digits (default 4).

...

Currently ignored.

Value

Invisibly returns the prLogistic object x. Called for its side effect of printing a formatted summary of the prevalence ratio estimates and confidence intervals to the console.